@@ -3,21 +3,19 @@ from .Settings import check_input, to_print
 
 
 class Canvas:
+    'Класс для рисования фигур на общем экране'
+
     def __init__(self, default_symbol: str = '-', size: int = 40):
         self.size = size
         self.default_symbol = default_symbol
         self.Board = [default_symbol] * size * size
 
-    def check_values(self, *args):
-        x = [0]
-        y = [0]
+    def _check_values(self, *args):
+        print('2', args, len(args))
+        x, y = [], []
 
         if len(args) == 0:
-            try:
-                x = self.x
-                y = self.y
-            except:
-                raise Error('У фигуры нет собственных точек')
+            raise Error('У фигуры нет собственных точек')
         else:
             x = list(args)[::2]
             y = list(args)[1::2]
@@ -31,24 +29,32 @@ class Canvas:
         return x, y
 
     def draw_dot(self, symbol: str = '', *args):
+        'Функция рисования в точке(ах) на общем экране'
+
         if symbol == '':
             symbol = self.default_symbol
 
-        x, y = self.check_values(*args)
+        x, y = self._check_values(*args)
 
         for i in range(len(x)):
             self.Board[x[i] + y[i] * self.size] = symbol[0]
 
     def fill(self, symbol: str = ''):
+        'Функция заполнения общего экрана символами'
+
         if symbol == '':
             symbol = self.default_symbol
 
         self.Board = [symbol[0]] * self.size * self.size
 
-    def get_dot(self, x=0, y=0):
+    def get_dot(self, x: int = 0, y: int = 0):
+        'Функция получения значения в точке'
+
         return self.Board[x + y * self.size]
 
     def print(self):
+        'Функция вывода общего экрана в консоль'
+
         a = list(range(self.size))
 
         print('    ', end='')
@@ -60,6 +66,8 @@ class Canvas:
             print(' ' * (2 - len(str(i))) + str(i) + '  ', '  '.join(self.Board[i * self.size: (i + 1) * self.size]))
 
     def print_c(self, symbol: str = ''):
+        'Функция цветного вывода общего экрана в консоль'
+
         if symbol == '':
             symbol = self.default_symbol
 
