@@ -8,6 +8,8 @@ background_color = 40
 
 
 def to_print(board: list, symbol: str):
+    'Функция цветного вывода на экран'
+
     size = int(len(board) ** 0.5)
 
     a = list(range(size))
@@ -35,6 +37,8 @@ def to_print(board: list, symbol: str):
 
 
 def check_input(x: list, size: int):
+    'Функция проверки введенных значений'
+
     s = 'На вход подаются числа от (0) до (размер поля - 1)'
 
     for i in x:
